<?php
/**
 * 2017 LiveChat
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Creative Commons License
 * This work is licensed under a Creative Commons Attribution 4.0 International License.
 *  @author	Michal Paszowski, LiveChat Inc. <support@livechatinc.com
 *  @copyright 2017 LiveChat Inc.
 *  @license   http://creativecommons.org/licenses/by/4.0/   Creative Commons Attribution 4.0 International License.
 */

if (!defined('_PS_VERSION_')) {
	exit;
}

class Livechat extends Module
{
	public function __construct()
	{
		$this->name = 'livechat';
		$this->tab = 'front_office_features';
		$this->author = 'LiveChat';
		$this->version = '1.3.1';
		$this->controllers = array('Livechat');
		$this->ps_versions_compliancy = array('min' => '1.6', 'max' => '1.7');
		$this->bootstrap = true;
		parent::__construct();
		$this->displayName = $this->l('LiveChat');
		$this->description = $this->l('LiveChat is a premium live chat and help desk software for customer service and online sales.');
	}
					
	public function install()
	{
		if (Shop::isFeatureActive()) {
			Shop::setContext(Shop::CONTEXT_ALL);
		}
				
		if (!parent::install() || !$this->registerHook('footer')) {
			return false;
		}
		
		if (!$this->installTab('AdminCatalog', 'AdminLivechat', 'My admin presta ajax')) {
			return false;
		}
		
		Configuration::updateValue('livechat_version', $this->version);
		Configuration::updateValue('livechat_cart', "10000");
		Configuration::updateValue('livechat_hide_on_mobile', '0');
		
		return true;
	}

	public function uninstall()
	{
		if (!parent::uninstall() ||
				!Configuration::deleteByName('livechat_version') ||
				!Configuration::deleteByName('livechat_licence') ||
				!Configuration::deleteByName('livechat_login') ||
				!Configuration::deleteByName('livechat_cart') ||
				!Configuration::deleteByName('livechat_hide_on_mobile')
		) {
			return false;
		}
		
		if (!$this->uninstallTab('AdminLivechat')) {
			return false;
		}
		
		return true;
	}

	public function getContent()
	{
		$livechat_login = (string)Configuration::get('livechat_login');
		$livechat_cart = (string)Configuration::get('livechat_cart');
		$livechat_version = (string)Configuration::get('livechat_version');
		$livechat_hide_on_mobile = Configuration::get('livechat_hide_on_mobile') ? 1 : 0;
		 
		if ($livechat_cart === "" || $livechat_cart === null) {
			$livechat_cart = "not_yet_set";
		}
		  
		return $this->showAdminForm($livechat_login, $livechat_cart, $_SERVER['REQUEST_URI'], $livechat_hide_on_mobile, $livechat_version);
	}

	public function hookfooter($params)
	{
		$link = new Link;
		$parameters = array("action" => "get_cart");
		$ajax_link = $link->getModuleLink('livechat', 'cartAjax', $parameters);
		
		if ($this->context->customer !== "" || $this->context->customer !== null) {
			$customer = $this->context->customer;
		}
						
		$this->context->smarty->assign(
			array(
				'license' => Configuration::get('livechat_licence'),
				'visitor' => $customer,
				'ajax_link' => $ajax_link,
				'cart_timing' => Configuration::get('livechat_cart'),
				'livechat_hide_on_mobile' => Configuration::get('livechat_hide_on_mobile')
			)
		);

		return $this->display(__FILE__, 'views/templates/front/livechat.tpl');
	}

	private function showAdminForm($login, $livechat_cart, $requestURI, $livechat_hide_on_mobile, $livechat_version)
	{
		$this->context->smarty->assign(
			array(
				'login' => $login,
				'requestURI' => $requestURI,
				'livechat_cart' => $livechat_cart,
				'livechat_hide_on_mobile' => $livechat_hide_on_mobile,
				'livechat_version' => $livechat_version,
				'token' => Tools::getAdminTokenLite('AdminLivechat')
			)
		);

		return $this->display(__FILE__, 'views/templates/admin/adminForm.tpl');
	}

	public function installTab($parent, $class_name, $name)
	{
		// Create new admin tab
		$tab = new Tab();
		$tab->id_parent = (int)Tab::getIdFromClassName($parent);
		$tab->name = array();
		foreach (Language::getLanguages(true) as $lang) {
			$tab->name[$lang['id_lang']] = $name;
		}
		$tab->class_name = $class_name;
		$tab->module = $this->name;
		$tab->active = 0;
		return $tab->add();
	}
	
	public function uninstallTab($class_name)
	{
		// Retrieve Tab ID
		$id_tab = (int)Tab::getIdFromClassName($class_name);
		// Load tab
		$tab = new Tab((int)$id_tab);
		// Delete it
		return $tab->delete();
	}
}
